@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Get;
 
-our $DATE = '2016-11-26'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -58,7 +58,7 @@ Bencher::Scenario::Accessors::Get - Benchmark attribute read/get
 
 =head1 VERSION
 
-This document describes version 0.13 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-26.
+This document describes version 0.14 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -122,53 +122,53 @@ L<Object::Tiny::RW::XS> 0.03
 
 L<Object::Tiny::XS> 1.01
 
-L<Perl::Examples::Accessors::Array> 0.11
+L<Perl::Examples::Accessors::Array> 0.12
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.11
+L<Perl::Examples::Accessors::ClassAccessor> 0.12
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.11
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.12
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.11
+L<Perl::Examples::Accessors::ClassInsideOut> 0.12
 
-L<Perl::Examples::Accessors::ClassStruct> 0.11
+L<Perl::Examples::Accessors::ClassStruct> 0.12
 
-L<Perl::Examples::Accessors::ClassTiny> 0.11
+L<Perl::Examples::Accessors::ClassTiny> 0.12
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.11
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.12
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.11
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.12
 
-L<Perl::Examples::Accessors::EvoClass> 0.11
+L<Perl::Examples::Accessors::EvoClass> 0.12
 
-L<Perl::Examples::Accessors::Hash> 0.11
+L<Perl::Examples::Accessors::Hash> 0.12
 
-L<Perl::Examples::Accessors::Mo> 0.11
+L<Perl::Examples::Accessors::Mo> 0.12
 
-L<Perl::Examples::Accessors::MojoBase> 0.11
+L<Perl::Examples::Accessors::MojoBase> 0.12
 
-L<Perl::Examples::Accessors::MojoBaseXS> 0.11
+L<Perl::Examples::Accessors::MojoBaseXS> 0.12
 
-L<Perl::Examples::Accessors::Moo> 0.11
+L<Perl::Examples::Accessors::Moo> 0.12
 
-L<Perl::Examples::Accessors::Moops> 0.11
+L<Perl::Examples::Accessors::Moops> 0.12
 
-L<Perl::Examples::Accessors::Moos> 0.11
+L<Perl::Examples::Accessors::Moos> 0.12
 
-L<Perl::Examples::Accessors::Moose> 0.11
+L<Perl::Examples::Accessors::Moose> 0.12
 
-L<Perl::Examples::Accessors::Mouse> 0.11
+L<Perl::Examples::Accessors::Mouse> 0.12
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.11
+L<Perl::Examples::Accessors::ObjectSimple> 0.12
 
-L<Perl::Examples::Accessors::ObjectTiny> 0.11
+L<Perl::Examples::Accessors::ObjectTiny> 0.12
 
-L<Perl::Examples::Accessors::ObjectTinyRW> 0.11
+L<Perl::Examples::Accessors::ObjectTinyRW> 0.12
 
-L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.11
+L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.12
 
-L<Perl::Examples::Accessors::ObjectTinyXS> 0.11
+L<Perl::Examples::Accessors::ObjectTinyXS> 0.12
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.11
+L<Perl::Examples::Accessors::SimpleAccessor> 0.12
 
 L<Simple::Accessor> 1.02
 
@@ -176,43 +176,11 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Object::Tiny::XS (perl_code)
+=item * Class::Tiny (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyXS->new(attr1 => 42); $o }; $o->attr1
-
-
-
-=item * Object::Tiny::RW::XS (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRWXS->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::Struct (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassStruct->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Evo::Class (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::EvoClass->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -224,11 +192,19 @@ Code template:
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Object::Tiny::XS (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyXS->new(attr1 => 42); $o }; $o->attr1
+
+
+
+=item * Object::Tiny (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectTiny->new(attr1 => 42); $o }; $o->attr1
 
 
 
@@ -240,19 +216,43 @@ Code template:
 
 
 
-=item * Object::Tiny::RW (perl_code)
+=item * Class::InsideOut (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRW->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
 
 
 
-=item * Mojo::Base::XS (perl_code)
+=item * no generator (hash-based) (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::MojoBaseXS->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Object::Tiny::RW::XS (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRWXS->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -264,6 +264,54 @@ Code template:
 
 
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::Struct (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassStruct->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Object::Tiny::RW (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRW->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -280,27 +328,19 @@ Code template:
 
 
 
-=item * Simple::Accessor (perl_code)
+=item * Moops (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Moops->new; $o->attr1(42); $o }; $o->attr1
 
 
 
-=item * Mouse (perl_code)
+=item * Mojo::Base::XS (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Mo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBaseXS->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -312,59 +352,19 @@ Code template:
 
 
 
-=item * no generator (array-based) (perl_code)
+=item * Class::XSAccessor::Array (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
 
 
 
-=item * Mojo::Base (perl_code)
+=item * Evo::Class (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Object::Tiny (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ObjectTiny->new(attr1 => 42); $o }; $o->attr1
-
-
-
-=item * Moops (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moops->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Object::Simple (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::EvoClass->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -396,34 +396,37 @@ Benchmark with default options (C<< bencher -m Accessors::Get >>):
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            |   1970000 |  507      |    1       | 4.3e-10 |      26 |
- | Class::InsideOut           |   2400000 |  410      |    1.2     | 3.7e-09 |      20 |
- | Simple::Accessor           |   2600000 |  380      |    1.3     | 4.3e-10 |      24 |
- | Evo::Class                 |   3800000 |  260      |    1.9     | 2.6e-09 |      20 |
- | Class::Struct              |   4080000 |  245      |    2.07    | 1.1e-10 |      20 |
- | Object::Tiny::RW           |   4588390 |  217.941  |    2.32703 |   0     |      20 |
- | no generator (hash-based)  |   4611000 |  216.9    |    2.339   | 1.1e-11 |      20 |
- | Mo                         |   4600000 |  220      |    2.3     | 3.1e-10 |      23 |
- | Class::Tiny                |   4897000 |  204.2    |    2.484   | 1.1e-11 |      20 |
- | Object::Simple             |   5090000 |  196      |    2.58    |   1e-10 |      20 |
- | Mojo::Base                 |   7000000 |  200      |    3       | 2.7e-09 |      20 |
- | Object::Tiny               |   7100000 |  140      |    3.6     | 2.3e-10 |      20 |
- | no generator (array-based) |   8000000 |  100      |    4       | 2.7e-09 |      20 |
- | Class::XSAccessor          |   9000000 |  110      |    4.5     | 8.3e-10 |      20 |
- | Mojo::Base::XS             |   9100000 |  110      |    4.6     | 4.4e-10 |      24 |
- | Moo                        |   9600000 |  100      |    4.9     |   1e-09 |      23 |
- | Mouse                      |  11000000 |   94      |    5.4     | 3.1e-10 |      30 |
- | Object::Tiny::RW::XS       |  12000000 |   86      |    5.9     | 2.4e-10 |      20 |
- | Class::XSAccessor::Array   |  10000000 |   80      |    6       | 8.9e-10 |      20 |
- | Object::Tiny::XS           |  13000000 |   79      |    6.4     | 2.9e-10 |      20 |
- | Moose                      |  13000000 |   79      |    6.5     | 7.4e-10 |      20 |
- | Moops                      |  13000000 |   78      |    6.5     | 2.6e-10 |      20 |
- | Class::Accessor::Array     |  10000000 |   80      |    7       | 9.5e-10 |      20 |
- | raw hash access            |  21000000 |   49      |   10       | 1.7e-10 |      29 |
- | raw array access           |  30791900 |   32.4761 |   15.6163  |   0     |      20 |
- | Moos                       | -70000000 |  -10      |  -40       | 8.5e-10 |      20 |
+ | Class::Accessor            |   2011000 |     497.3 |      1     | 1.2e-11 |      22 |
+ | Simple::Accessor           |   2834000 |     352.8 |      1.409 | 1.1e-11 |      20 |
+ | Class::InsideOut           |   3250000 |     308   |      1.61  |   3e-10 |      21 |
+ | Class::Struct              |   4320000 |     231   |      2.15  |   1e-10 |      20 |
+ | Mojo::Base                 |   4900000 |     210   |      2.4   | 3.1e-10 |      20 |
+ | Mo                         |   5000000 |     200   |      2.5   | 4.2e-10 |      20 |
+ | Object::Tiny::RW           |   5588000 |     179   |      2.779 | 1.1e-11 |      20 |
+ | no generator (array-based) |   5588000 |     178.9 |      2.779 | 1.1e-11 |      20 |
+ | Object::Simple             |   5800000 |     170   |      2.9   | 3.1e-10 |      20 |
+ | Evo::Class                 |   5846000 |     171   |      2.907 | 1.2e-11 |      20 |
+ | no generator (hash-based)  |   6010000 |     166   |      2.99  |   1e-10 |      20 |
+ | Class::Accessor::Array     |   6400000 |     160   |      3.2   | 3.1e-10 |      20 |
+ | Moose                      |   6600000 |     150   |      3.3   | 4.2e-10 |      20 |
+ | Class::Tiny                |   6800000 |     150   |      3.4   | 2.9e-10 |      20 |
+ | Object::Tiny               |   8800000 |     110   |      4.4   | 1.9e-10 |      23 |
+ | Mouse                      |  10000000 |      99   |      5     | 1.4e-10 |      20 |
+ | Object::Tiny::XS           |  11400000 |      87.9 |      5.66  | 5.3e-11 |      20 |
+ | Mojo::Base::XS             |  12000000 |      87   |      5.7   | 3.4e-10 |      20 |
+ | Moos                       |  12000000 |      81   |      6.1   | 1.6e-10 |      20 |
+ | Moops                      |  13000000 |      78   |      6.3   | 1.6e-10 |      20 |
+ | Object::Tiny::RW::XS       |  13000000 |      77   |      6.4   | 2.4e-10 |      24 |
+ | Class::XSAccessor          |  13000000 |      75   |      6.6   | 1.5e-10 |      21 |
+ | Moo                        |  14500000 |      69.1 |      7.2   | 4.6e-11 |      21 |
+ | Class::XSAccessor::Array   |  19000000 |      53   |      9.3   | 6.3e-11 |      20 |
+ | raw hash access            |  32000000 |      32   |     16     | 2.1e-10 |      20 |
+ | raw array access           |  49500000 |      20.2 |     24.6   |   1e-11 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Accessors>.
@@ -448,7 +451,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
