@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
-our $DATE = '2016-11-26'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -54,7 +54,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.13 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-26.
+This document describes version 0.14 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -118,49 +118,49 @@ L<Object::Tiny::RW::XS> 0.03
 
 L<Object::Tiny::XS> 1.01
 
-L<Perl::Examples::Accessors::Array> 0.11
+L<Perl::Examples::Accessors::Array> 0.12
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.11
+L<Perl::Examples::Accessors::ClassAccessor> 0.12
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.11
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.12
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.11
+L<Perl::Examples::Accessors::ClassInsideOut> 0.12
 
-L<Perl::Examples::Accessors::ClassStruct> 0.11
+L<Perl::Examples::Accessors::ClassStruct> 0.12
 
-L<Perl::Examples::Accessors::ClassTiny> 0.11
+L<Perl::Examples::Accessors::ClassTiny> 0.12
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.11
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.12
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.11
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.12
 
-L<Perl::Examples::Accessors::EvoClass> 0.11
+L<Perl::Examples::Accessors::EvoClass> 0.12
 
-L<Perl::Examples::Accessors::Hash> 0.11
+L<Perl::Examples::Accessors::Hash> 0.12
 
-L<Perl::Examples::Accessors::Mo> 0.11
+L<Perl::Examples::Accessors::Mo> 0.12
 
-L<Perl::Examples::Accessors::MojoBase> 0.11
+L<Perl::Examples::Accessors::MojoBase> 0.12
 
-L<Perl::Examples::Accessors::MojoBaseXS> 0.11
+L<Perl::Examples::Accessors::MojoBaseXS> 0.12
 
-L<Perl::Examples::Accessors::Moo> 0.11
+L<Perl::Examples::Accessors::Moo> 0.12
 
-L<Perl::Examples::Accessors::Moops> 0.11
+L<Perl::Examples::Accessors::Moops> 0.12
 
-L<Perl::Examples::Accessors::Moos> 0.11
+L<Perl::Examples::Accessors::Moos> 0.12
 
-L<Perl::Examples::Accessors::Moose> 0.11
+L<Perl::Examples::Accessors::Moose> 0.12
 
-L<Perl::Examples::Accessors::Mouse> 0.11
+L<Perl::Examples::Accessors::Mouse> 0.12
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.11
+L<Perl::Examples::Accessors::ObjectSimple> 0.12
 
-L<Perl::Examples::Accessors::ObjectTinyRW> 0.11
+L<Perl::Examples::Accessors::ObjectTinyRW> 0.12
 
-L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.11
+L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.12
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.11
+L<Perl::Examples::Accessors::SimpleAccessor> 0.12
 
 L<Simple::Accessor> 1.02
 
@@ -168,35 +168,11 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Object::Tiny::RW::XS (perl_code)
+=item * Class::Tiny (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRWXS->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Struct (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassStruct->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
-
-
-
-=item * Evo::Class (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::EvoClass->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
 
 
 
@@ -208,14 +184,6 @@ Code template:
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
-
-
-
 =item * Class::XSAccessor (perl_code)
 
 Code template:
@@ -224,19 +192,43 @@ Code template:
 
 
 
-=item * Object::Tiny::RW (perl_code)
+=item * Class::InsideOut (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRW->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
 
 
 
-=item * Mojo::Base::XS (perl_code)
+=item * no generator (hash-based) (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::MojoBaseXS->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
+=item * Object::Tiny::RW::XS (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRWXS->new; $o }; $o->attr1(42)
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
+
+
+
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
 
 
 
@@ -248,6 +240,54 @@ Code template:
 
 
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::Struct (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassStruct->new; $o }; $o->attr1(42)
+
+
+
+=item * Object::Tiny::RW (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectTinyRW->new; $o }; $o->attr1(42)
+
+
+
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -264,27 +304,19 @@ Code template:
 
 
 
-=item * Simple::Accessor (perl_code)
+=item * Moops (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Moops->new; $o }; $o->attr1(42)
 
 
 
-=item * Mouse (perl_code)
+=item * Mojo::Base::XS (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
-
-
-
-=item * Mo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBaseXS->new; $o }; $o->attr1(42)
 
 
 
@@ -296,51 +328,19 @@ Code template:
 
 
 
-=item * no generator (array-based) (perl_code)
+=item * Class::XSAccessor::Array (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
 
 
 
-=item * Mojo::Base (perl_code)
+=item * Evo::Class (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
-
-
-
-=item * Moops (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moops->new; $o }; $o->attr1(42)
-
-
-
-=item * Object::Simple (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::EvoClass->new; $o }; $o->attr1(42)
 
 
 
@@ -372,32 +372,35 @@ Benchmark with default options (C<< bencher -m Accessors::Set >>):
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Simple::Accessor           |    198000 |  5.04     |      1     | 1.7e-09 |      20 |
- | Class::Accessor            |   1600000 |  0.627    |      8.04  | 3.9e-10 |      20 |
- | Class::InsideOut           |   1970000 |  0.507    |      9.93  | 2.1e-10 |      20 |
- | Object::Tiny::RW           |   2970000 |  0.337    |     15     | 1.7e-10 |      32 |
- | Evo::Class                 |   3200000 |  0.31     |     16     | 8.5e-10 |      20 |
- | Class::Struct              |   3200000 |  0.31     |     16     | 8.2e-10 |      21 |
- | Class::Tiny                |   3400000 |  0.29     |     17     | 4.2e-10 |      20 |
- | Moose                      |   3440000 |  0.291    |     17.3   | 2.1e-10 |      23 |
- | Mojo::Base                 |   3550000 |  0.282    |     17.9   | 1.1e-10 |      20 |
- | Object::Simple             |   4200000 |  0.24     |     21     | 5.1e-10 |      20 |
- | no generator (array-based) |   4500000 |  0.22     |     23     | 3.5e-10 |      23 |
- | no generator (hash-based)  |   4600000 |  0.22     |     23     | 4.3e-10 |      20 |
- | Mo                         |   4800000 |  0.21     |     24     | 4.8e-10 |      29 |
- | Class::Accessor::Array     |   5400000 |  0.18     |     27     | 4.4e-10 |      20 |
- | Mojo::Base::XS             |   6600000 |  0.15     |     33     | 4.2e-10 |      20 |
- | Moos                       |   6772030 |  0.147666 |     34.135 |   0     |      20 |
- | Class::XSAccessor          |   7100000 |  0.14     |     36     | 3.1e-10 |      20 |
- | Moo                        |   8000000 |  0.13     |     40     | 2.3e-10 |      25 |
- | Object::Tiny::RW::XS       |   8330000 |  0.12     |     42     | 3.5e-11 |      20 |
- | Moops                      |   8629000 |  0.1159   |     43.49  | 1.2e-11 |      20 |
- | Class::XSAccessor::Array   |   8800000 |  0.11     |     44     | 1.7e-10 |      20 |
- | Mouse                      |  10000000 |  0.07     |     70     | 7.3e-10 |      20 |
- | raw hash access            |  15000000 |  0.067    |     75     | 1.1e-10 |      20 |
- | raw array access           |  18000000 |  0.056    |     91     | 1.1e-10 |      20 |
+ | Simple::Accessor           |    264000 |    3.79   |       1    | 1.4e-09 |      30 |
+ | Class::Accessor            |   1700000 |    0.57   |       6.6  | 8.1e-10 |      21 |
+ | Class::InsideOut           |   2550000 |    0.392  |       9.65 | 2.1e-10 |      20 |
+ | Evo::Class                 |   3900000 |    0.26   |      15    | 4.2e-10 |      20 |
+ | Class::Struct              |   4330000 |    0.231  |      16.4  | 8.7e-11 |      29 |
+ | Moose                      |   4337000 |    0.2306 |      16.42 |   1e-11 |      20 |
+ | Object::Tiny::RW           |   4400000 |    0.23   |      17    | 4.2e-10 |      20 |
+ | Mo                         |   4480000 |    0.223  |      16.9  |   1e-10 |      20 |
+ | Class::Accessor::Array     |   4561000 |    0.2193 |      17.27 | 1.1e-11 |      24 |
+ | Mojo::Base                 |   5030000 |    0.199  |      19    |   1e-10 |      20 |
+ | Class::Tiny                |   5100000 |    0.2    |      19    | 4.4e-10 |      21 |
+ | Object::Simple             |   5241000 |    0.1908 |      19.84 | 1.2e-11 |      20 |
+ | no generator (hash-based)  |   5860000 |    0.171  |      22.2  | 9.8e-11 |      26 |
+ | no generator (array-based) |   6399000 |    0.1563 |      24.23 | 9.8e-12 |      20 |
+ | Mouse                      |   9180000 |    0.109  |      34.7  | 1.1e-11 |      26 |
+ | Moops                      |   9500000 |    0.11   |      36    | 2.1e-10 |      20 |
+ | Mojo::Base::XS             |   9500000 |    0.1    |      36    | 2.6e-10 |      20 |
+ | Class::XSAccessor          |   9550000 |    0.105  |      36.2  | 1.1e-11 |      20 |
+ | Moos                       |  10000000 |    0.098  |      39    | 1.6e-10 |      20 |
+ | Object::Tiny::RW::XS       |  11000000 |    0.095  |      40    |   2e-10 |      21 |
+ | Class::XSAccessor::Array   |  11000000 |    0.094  |      40    | 1.5e-10 |      22 |
+ | Moo                        |  12000000 |    0.082  |      46    | 2.1e-10 |      21 |
+ | raw array access           |  10000000 |    0.07   |      50    | 4.2e-09 |      20 |
+ | raw hash access            |  15000000 |    0.067  |      56    | 1.6e-10 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Accessors>.
@@ -422,7 +425,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
