@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::ClassStartup;
 
-our $VERSION = 0.13; # VERSION
+our $VERSION = 0.14; # VERSION
 
 our $results = [
   [
@@ -8,211 +8,289 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0039,
-        mod_overhead_time => 193.4,
+        errors => 0.00021,
+        mod_overhead_time => 165.4,
         participant => "Perl::Examples::Accessors::Moops",
-        samples => 20,
-        time => 200,
+        proc_private_dirty_size => 0.92,
+        proc_rss_size => 4.3,
+        proc_size => 18,
+        samples => 21,
+        time => 170,
         vs_slowest => 1,
       },
       {
-        errors => 0.0014,
-        mod_overhead_time => 203.4,
+        errors => 0.00037,
+        mod_overhead_time => 155.4,
         participant => "Perl::Examples::Accessors::Moose",
+        proc_private_dirty_size => 1.5,
+        proc_rss_size => 4.9,
+        proc_size => 19,
         samples => 20,
-        time => 210,
+        time => 160,
         vs_slowest => 1.1,
       },
       {
-        errors => 0.0029,
-        mod_overhead_time => 63.4,
-        participant => "Perl::Examples::Accessors::Moo",
-        samples => 20,
-        time => 70,
-        vs_slowest => 3,
-      },
-      {
-        errors => 0.0021,
-        mod_overhead_time => 53.4,
+        errors => 7e-05,
+        mod_overhead_time => 31.4,
         participant => "Perl::Examples::Accessors::EvoClass",
-        samples => 21,
-        time => 60,
-        vs_slowest => 4,
+        proc_private_dirty_size => 0.82,
+        proc_rss_size => 4.1,
+        proc_size => 16,
+        samples => 20,
+        time => 36,
+        vs_slowest => 4.7,
       },
       {
-        errors => 0.00053,
-        mod_overhead_time => 33.4,
+        errors => 4.4e-05,
+        mod_overhead_time => 25.4,
+        participant => "Perl::Examples::Accessors::Moo",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
+        samples => 20,
+        time => 30,
+        vs_slowest => 5.6,
+      },
+      {
+        errors => 7e-05,
+        mod_overhead_time => 19.4,
         participant => "Perl::Examples::Accessors::Mouse",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
         samples => 20,
-        time => 40,
-        vs_slowest => 6,
+        time => 24,
+        vs_slowest => 6.9,
       },
       {
-        errors => 0.00062,
-        mod_overhead_time => 23.4,
-        participant => "Perl::Examples::Accessors::Moos",
-        samples => 22,
-        time => 30,
-        vs_slowest => 8,
-      },
-      {
-        errors => 0.00091,
-        mod_overhead_time => 23.4,
-        participant => "Perl::Examples::Accessors::ClassXSAccessorArray",
-        samples => 20,
-        time => 30,
-        vs_slowest => 9,
-      },
-      {
-        errors => 0.00043,
-        mod_overhead_time => 13.4,
-        participant => "Perl::Examples::Accessors::MojoBase",
-        samples => 22,
-        time => 20,
-        vs_slowest => 10,
-      },
-      {
-        errors => 0.00056,
-        mod_overhead_time => 13.4,
-        participant => "Perl::Examples::Accessors::ClassAccessor",
-        samples => 20,
-        time => 20,
-        vs_slowest => 10,
-      },
-      {
-        errors => 4.9e-05,
+        errors => 4.5e-05,
         mod_overhead_time => 14.4,
-        participant => "Perl::Examples::Accessors::ClassInsideOut",
+        participant => "Perl::Examples::Accessors::Moos",
+        proc_private_dirty_size => 0.88,
+        proc_rss_size => 4.1,
+        proc_size => 16,
         samples => 22,
-        time => 21,
+        time => 19,
+        vs_slowest => 8.6,
+      },
+      {
+        errors => 8.1e-05,
+        mod_overhead_time => 11.4,
+        participant => "Perl::Examples::Accessors::ClassInsideOut",
+        proc_private_dirty_size => 0.84,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 21,
+        time => 16,
+        vs_slowest => 10,
+      },
+      {
+        errors => 7.7e-05,
+        mod_overhead_time => 10.4,
+        participant => "Perl::Examples::Accessors::MojoBase",
+        proc_private_dirty_size => 0.84,
+        proc_rss_size => 4.1,
+        proc_size => 16,
+        samples => 21,
+        time => 15,
+        vs_slowest => 11,
+      },
+      {
+        errors => 4.8e-05,
+        mod_overhead_time => 9.4,
+        participant => "Perl::Examples::Accessors::ClassTiny",
+        proc_private_dirty_size => 3.8,
+        proc_rss_size => 7.3,
+        proc_size => 27,
+        samples => 20,
+        time => 14,
         vs_slowest => 12,
       },
       {
         errors => 5e-05,
-        mod_overhead_time => 11.4,
-        participant => "Perl::Examples::Accessors::ClassTiny",
-        samples => 20,
-        time => 18,
+        mod_overhead_time => 7.4,
+        participant => "Perl::Examples::Accessors::ClassStruct",
+        proc_private_dirty_size => 0.88,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 22,
+        time => 12,
         vs_slowest => 13,
       },
       {
-        errors => 0.00025,
-        mod_overhead_time => 13.4,
-        participant => "Perl::Examples::Accessors::ClassXSAccessor",
-        samples => 20,
-        time => 20,
-        vs_slowest => 10,
-      },
-      {
-        errors => 7.5e-05,
-        mod_overhead_time => 10.4,
-        participant => "Perl::Examples::Accessors::ClassStruct",
-        samples => 20,
-        time => 17,
+        errors => 4.5e-05,
+        mod_overhead_time => 7.4,
+        participant => "Perl::Examples::Accessors::ObjectSimple",
+        proc_private_dirty_size => 2.3,
+        proc_rss_size => 5.8,
+        proc_size => 26,
+        samples => 22,
+        time => 12,
         vs_slowest => 14,
       },
       {
-        errors => 8.2e-05,
-        mod_overhead_time => 9.4,
-        participant => "Perl::Examples::Accessors::ObjectSimple",
+        errors => 3.3e-05,
+        mod_overhead_time => 7.4,
+        participant => "Perl::Examples::Accessors::ClassXSAccessorArray",
+        proc_private_dirty_size => 4.1,
+        proc_rss_size => 7.6,
+        proc_size => 27,
         samples => 20,
-        time => 16,
-        vs_slowest => 15,
+        time => 12,
+        vs_slowest => 14,
       },
       {
-        errors => 8e-05,
-        mod_overhead_time => 8.4,
-        participant => "Perl::Examples::Accessors::ObjectTinyRWXS",
-        samples => 20,
-        time => 15,
-        vs_slowest => 15,
-      },
-      {
-        errors => 1.6e-05,
-        mod_overhead_time => 8.4,
+        errors => 4.9e-05,
+        mod_overhead_time => 7.4,
         participant => "Perl::Examples::Accessors::ObjectTinyXS",
+        proc_private_dirty_size => 0.83,
+        proc_rss_size => 4.1,
+        proc_size => 16,
         samples => 20,
-        time => 15,
-        vs_slowest => 16,
+        time => 12,
+        vs_slowest => 14,
       },
       {
-        errors => 0.0004,
-        mod_overhead_time => 3.4,
-        participant => "Perl::Examples::Accessors::SimpleAccessor",
-        samples => 21,
-        time => 10,
-        vs_slowest => 20,
-      },
-      {
-        errors => 0.00035,
-        mod_overhead_time => 3.4,
-        participant => "Perl::Examples::Accessors::ObjectTiny",
-        samples => 21,
-        time => 10,
-        vs_slowest => 20,
-      },
-      {
-        errors => 1.3e-05,
-        mod_overhead_time => 4.4,
-        participant => "Perl::Examples::Accessors::MojoBaseXS",
+        errors => 6.6e-05,
+        mod_overhead_time => 7.4,
+        participant => "Perl::Examples::Accessors::ClassAccessor",
+        proc_private_dirty_size => 16,
+        proc_rss_size => 20,
+        proc_size => 76,
         samples => 20,
-        time => 11,
-        vs_slowest => 22,
+        time => 12,
+        vs_slowest => 14,
       },
       {
         errors => 6.7e-05,
-        mod_overhead_time => 3.4,
-        participant => "Perl::Examples::Accessors::ClassAccessorArray",
+        mod_overhead_time => 6.4,
+        participant => "Perl::Examples::Accessors::ClassXSAccessor",
+        proc_private_dirty_size => 1.9,
+        proc_rss_size => 5.2,
+        proc_size => 19,
         samples => 20,
-        time => 10,
-        vs_slowest => 24,
+        time => 11,
+        vs_slowest => 15,
       },
       {
-        errors => 4.7e-05,
-        mod_overhead_time => 3.1,
-        participant => "Perl::Examples::Accessors::Mo",
+        errors => 1.7e-05,
+        mod_overhead_time => 6.4,
+        participant => "Perl::Examples::Accessors::ObjectTinyRWXS",
+        proc_private_dirty_size => 3.2,
+        proc_rss_size => 6.6,
+        proc_size => 24,
         samples => 20,
-        time => 9.7,
-        vs_slowest => 24,
+        time => 11,
+        vs_slowest => 15,
       },
       {
-        errors => 0.0002,
-        mod_overhead_time => 2.4,
-        participant => "Perl::Examples::Accessors::Scalar",
+        errors => 1.7e-05,
+        mod_overhead_time => 3.7,
+        participant => "Perl::Examples::Accessors::MojoBaseXS",
+        proc_private_dirty_size => 15,
+        proc_rss_size => 18,
+        proc_size => 50,
         samples => 20,
-        time => 9,
-        vs_slowest => 30,
+        time => 8.3,
+        vs_slowest => 20,
       },
       {
-        errors => 1.4e-05,
-        mod_overhead_time => 1.3,
-        participant => "Perl::Examples::Accessors::ObjectTinyRW",
+        errors => 2.8e-05,
+        mod_overhead_time => 2.8,
+        participant => "Perl::Examples::Accessors::SimpleAccessor",
+        proc_private_dirty_size => 1.5,
+        proc_rss_size => 5,
+        proc_size => 17,
         samples => 20,
-        time => 7.9,
-        vs_slowest => 30,
-      },
-      {
-        errors => 3.5e-05,
-        mod_overhead_time => 0.9,
-        participant => "Perl::Examples::Accessors::Array",
-        samples => 20,
-        time => 7.5,
-        vs_slowest => 32,
+        time => 7.4,
+        vs_slowest => 23,
       },
       {
         errors => 1.2e-05,
-        mod_overhead_time => 0.4,
-        participant => "Perl::Examples::Accessors::Hash",
-        samples => 21,
+        mod_overhead_time => 2.4,
+        participant => "Perl::Examples::Accessors::Mo",
+        proc_private_dirty_size => 1.8,
+        proc_rss_size => 5.2,
+        proc_size => 21,
+        samples => 20,
         time => 7,
-        vs_slowest => 34,
+        vs_slowest => 24,
       },
       {
-        errors => 1.3e-05,
+        errors => 3e-05,
+        mod_overhead_time => 2.4,
+        participant => "Perl::Examples::Accessors::ClassAccessorArray",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
+        samples => 20,
+        time => 7,
+        vs_slowest => 24,
+      },
+      {
+        errors => 2.5e-05,
+        mod_overhead_time => 1.2,
+        participant => "Perl::Examples::Accessors::ObjectTinyRW",
+        proc_private_dirty_size => 0.88,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 20,
+        time => 5.8,
+        vs_slowest => 29,
+      },
+      {
+        errors => 2.1e-05,
+        mod_overhead_time => 1.1,
+        participant => "Perl::Examples::Accessors::ObjectTiny",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
+        samples => 20,
+        time => 5.7,
+        vs_slowest => 29,
+      },
+      {
+        errors => 2.3e-05,
+        mod_overhead_time => 0.5,
+        participant => "Perl::Examples::Accessors::Scalar",
+        proc_private_dirty_size => 0.88,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 20,
+        time => 5.1,
+        vs_slowest => 33,
+      },
+      {
+        errors => 1.4e-05,
+        mod_overhead_time => 0.4,
+        participant => "Perl::Examples::Accessors::Hash",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.9,
+        proc_size => 19,
+        samples => 20,
+        time => 5,
+        vs_slowest => 33,
+      },
+      {
+        errors => 8.7e-06,
+        mod_overhead_time => 0.4,
+        participant => "Perl::Examples::Accessors::Array",
+        proc_private_dirty_size => 0.89,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 20,
+        time => 5,
+        vs_slowest => 33,
+      },
+      {
+        errors => 5.3e-06,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
+        proc_private_dirty_size => 1.7,
+        proc_rss_size => 5.2,
+        proc_size => 19,
         samples => 20,
-        time => 6.6,
+        time => 4.6,
         vs_slowest => 36,
       },
     ],
@@ -336,7 +414,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2100.054,
+                                              speed                        => 2636.976,
                                               stepping                     => 4,
                                             },
                                             {
@@ -451,7 +529,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2200.023,
+                                              speed                        => 2776.046,
                                               stepping                     => 4,
                                             },
                                             {
@@ -566,7 +644,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2200.023,
+                                              speed                        => 2600.007,
                                               stepping                     => 4,
                                             },
                                             {
@@ -681,13 +759,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2199.968,
+                                              speed                        => 2763.468,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 23.0474898815155,
+      "func.elapsed_time"              => 15.0962941646576,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::Accessors::ClassStartup" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Class::Accessor" => 0.34,
@@ -713,31 +792,31 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors::Array" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
-                                            "Perl::Examples::Accessors::Hash" => 0.11,
-                                            "Perl::Examples::Accessors::Mo" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
-                                            "Perl::Examples::Accessors::Moo" => 0.11,
-                                            "Perl::Examples::Accessors::Moops" => 0.11,
-                                            "Perl::Examples::Accessors::Moos" => 0.11,
-                                            "Perl::Examples::Accessors::Moose" => 0.11,
-                                            "Perl::Examples::Accessors::Mouse" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.11,
-                                            "Perl::Examples::Accessors::Scalar" => 0.11,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::Array" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.12,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.12,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.12,
+                                            "Perl::Examples::Accessors::Hash" => 0.12,
+                                            "Perl::Examples::Accessors::Mo" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.12,
+                                            "Perl::Examples::Accessors::Moo" => 0.12,
+                                            "Perl::Examples::Accessors::Moops" => 0.12,
+                                            "Perl::Examples::Accessors::Moos" => 0.12,
+                                            "Perl::Examples::Accessors::Moose" => 0.12,
+                                            "Perl::Examples::Accessors::Mouse" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.12,
+                                            "Perl::Examples::Accessors::Scalar" => 0.12,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.12,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -772,13 +851,26 @@ our $results = [
       "func.scenario_module_mtime"     => 1473472033,
       "func.scenario_module_sha1sum"   => "9e49211383260a4cd180d04ca81586923477f8d6",
       "func.scenario_module_sha256sum" => "97f5aceb8e2616fe9259463dbd8ab2edba1558acd2dfec6bf44b04520ebf16f5",
-      "func.time_end"                  => 1480141027.24386,
+      "func.time_end"                  => 1485326537.40748,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1480141004.19637,
-      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
-      "table.field_units"              => [undef, "ms", "ms"],
+      "func.time_start"                => 1485326522.31119,
+      "table.field_aligns"             => [
+                                            "left",
+                                            "left",
+                                            "left",
+                                            "left",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                          ],
+      "table.field_units"              => [undef, "MB", "MB", "MB", "ms", "ms"],
       "table.fields"                   => [
                                             "participant",
+                                            "proc_private_dirty_size",
+                                            "proc_rss_size",
+                                            "proc_size",
                                             "time",
                                             "mod_overhead_time",
                                             "vs_slowest",
