@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::Construction;
 
-our $VERSION = 0.13; # VERSION
+our $VERSION = 0.14; # VERSION
 
 our $results = [
   [
@@ -8,204 +8,204 @@ our $results = [
     "OK",
     [
       {
-        errors => 4.3e-08,
+        errors => 3.5e-11,
         participant => "Moos",
-        rate => 87000,
-        samples => 20,
-        time => 12,
+        rate => 142190,
+        samples => 23,
+        time => 7.033,
         vs_slowest => 1,
       },
       {
-        errors => 8.1e-09,
+        errors => 3.3e-09,
         participant => "Class::InsideOut",
-        rate => 200000,
-        samples => 21,
-        time => 4.9,
+        rate => 340000,
+        samples => 20,
+        time => 3,
         vs_slowest => 2.4,
       },
       {
-        errors => 6.1e-09,
+        errors => 3e-09,
         participant => "Simple::Accessor",
-        rate => 280000,
-        samples => 24,
-        time => 3.5,
-        vs_slowest => 3.3,
+        rate => 460000,
+        samples => 25,
+        time => 2.2,
+        vs_slowest => 3.2,
+      },
+      {
+        errors => 3.4e-09,
+        participant => "Class::Tiny",
+        rate => 650000,
+        samples => 20,
+        time => 1.5,
+        vs_slowest => 4.6,
+      },
+      {
+        errors => 1.2e-09,
+        participant => "Moose",
+        rate => 820000,
+        samples => 20,
+        time => 1.2,
+        vs_slowest => 5.8,
+      },
+      {
+        errors => 1.2e-09,
+        participant => "Evo::Class",
+        rate => 830000,
+        samples => 21,
+        time => 1.2,
+        vs_slowest => 5.9,
+      },
+      {
+        errors => 4.2e-10,
+        participant => "Mo",
+        rate => 1080000,
+        samples => 20,
+        time => 0.928,
+        vs_slowest => 7.58,
+      },
+      {
+        errors => 3.4e-11,
+        participant => "Class::Struct",
+        rate => 1217000,
+        samples => 20,
+        time => 0.8217,
+        vs_slowest => 8.559,
+      },
+      {
+        errors => 4e-10,
+        participant => "Moops",
+        rate => 1310000,
+        samples => 22,
+        time => 0.763,
+        vs_slowest => 9.22,
+      },
+      {
+        errors => 1.2e-11,
+        participant => "Moo",
+        rate => 1345000,
+        samples => 20,
+        time => 0.7435,
+        vs_slowest => 9.46,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "Class::Accessor",
+        rate => 1539000,
+        samples => 20,
+        time => 0.6496,
+        vs_slowest => 10.83,
+      },
+      {
+        errors => 6.2e-10,
+        participant => "Mouse",
+        rate => 1700000,
+        samples => 20,
+        time => 0.58,
+        vs_slowest => 12,
+      },
+      {
+        errors => 3.5e-11,
+        participant => "no generator (array-based)",
+        rate => 2129000,
+        samples => 20,
+        time => 0.4698,
+        vs_slowest => 14.97,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "no generator (hash-based)",
+        rate => 2585000,
+        samples => 20,
+        time => 0.3868,
+        vs_slowest => 18.18,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "Object::Simple",
+        rate => 2686000,
+        samples => 20,
+        time => 0.3723,
+        vs_slowest => 18.89,
+      },
+      {
+        errors => 1.2e-11,
+        participant => "Mojo::Base",
+        rate => 2746000,
+        samples => 20,
+        time => 0.3642,
+        vs_slowest => 19.31,
       },
       {
         errors => 8.3e-10,
-        participant => "Class::Tiny",
-        rate => 384000,
-        samples => 20,
-        time => 2.6,
-        vs_slowest => 4.43,
-      },
-      {
-        errors => 7.3e-09,
-        participant => "Moose",
-        rate => 470000,
-        samples => 21,
-        time => 2.1,
-        vs_slowest => 5.4,
-      },
-      {
-        errors => 7.3e-10,
-        participant => "Evo::Class",
-        rate => 513000,
-        samples => 26,
-        time => 1.95,
-        vs_slowest => 5.92,
-      },
-      {
-        errors => 3.3e-09,
-        participant => "Mo",
-        rate => 620000,
-        samples => 20,
-        time => 1.6,
-        vs_slowest => 7.2,
-      },
-      {
-        errors => 1.8e-09,
-        participant => "Class::Struct",
-        rate => 720000,
-        samples => 28,
-        time => 1.4,
-        vs_slowest => 8.3,
-      },
-      {
-        errors => 1.5e-09,
-        participant => "Moops",
-        rate => 760000,
-        samples => 24,
-        time => 1.3,
-        vs_slowest => 8.8,
-      },
-      {
-        errors => 3.8e-10,
-        participant => "Moo",
-        rate => 817000,
-        samples => 24,
-        time => 1.22,
-        vs_slowest => 9.42,
-      },
-      {
-        errors => 0,
-        participant => "Class::Accessor",
-        rate => 942248,
-        samples => 20,
-        time => 1.06129,
-        vs_slowest => 10.8673,
-      },
-      {
-        errors => 3.8e-09,
-        participant => "Mouse",
-        rate => 950000,
-        samples => 20,
-        time => 1.1,
-        vs_slowest => 11,
-      },
-      {
-        errors => 2.1e-09,
-        participant => "no generator (array-based)",
-        rate => 1200000,
-        samples => 20,
-        time => 0.83,
-        vs_slowest => 14,
-      },
-      {
-        errors => 1.7e-09,
-        participant => "Object::Simple",
-        rate => 1400000,
-        samples => 20,
-        time => 0.72,
-        vs_slowest => 16,
-      },
-      {
-        errors => 1.7e-09,
-        participant => "no generator (hash-based)",
-        rate => 1400000,
-        samples => 20,
-        time => 0.7,
-        vs_slowest => 16,
-      },
-      {
-        errors => 2.7e-09,
-        participant => "Mojo::Base",
-        rate => 1400000,
-        samples => 20,
-        time => 0.7,
-        vs_slowest => 17,
-      },
-      {
-        errors => 1.7e-09,
-        participant => "Object::Tiny",
-        rate => 1500000,
-        samples => 20,
-        time => 0.67,
-        vs_slowest => 17,
-      },
-      {
-        errors => 1e-09,
-        participant => "Class::Accessor::Array",
-        rate => 1700000,
-        samples => 20,
-        time => 0.6,
-        vs_slowest => 19,
-      },
-      {
-        errors => 1.8e-10,
-        participant => "no generator (scalar-based)",
-        rate => 1790000,
-        samples => 28,
-        time => 0.56,
-        vs_slowest => 20.6,
-      },
-      {
-        errors => 6.4e-10,
         participant => "Object::Tiny::RW",
-        rate => 1800000,
-        samples => 23,
-        time => 0.54,
-        vs_slowest => 21,
-      },
-      {
-        errors => 1.6e-08,
-        participant => "Object::Tiny::RW::XS",
-        rate => 2000000,
-        samples => 23,
-        time => 0.5,
+        rate => 2800000,
+        samples => 20,
+        time => 0.35,
         vs_slowest => 20,
       },
       {
-        errors => 1e-09,
-        participant => "Object::Tiny::XS",
-        rate => 2600000,
+        errors => 1.1e-11,
+        participant => "Object::Tiny",
+        rate => 2833000,
         samples => 20,
-        time => 0.39,
-        vs_slowest => 30,
+        time => 0.353,
+        vs_slowest => 19.92,
       },
       {
-        errors => 2.9e-09,
+        errors => 1.1e-11,
+        participant => "Class::Accessor::Array",
+        rate => 2966000,
+        samples => 22,
+        time => 0.3372,
+        vs_slowest => 20.86,
+      },
+      {
+        errors => 2.1e-10,
+        participant => "no generator (scalar-based)",
+        rate => 3000000,
+        samples => 20,
+        time => 0.334,
+        vs_slowest => 21.1,
+      },
+      {
+        errors => 1.4e-10,
+        participant => "Class::XSAccessor",
+        rate => 4240000,
+        samples => 21,
+        time => 0.236,
+        vs_slowest => 29.8,
+      },
+      {
+        errors => 1e-10,
+        participant => "Object::Tiny::RW::XS",
+        rate => 4270000,
+        samples => 20,
+        time => 0.234,
+        vs_slowest => 30.1,
+      },
+      {
+        errors => 4.5e-11,
+        participant => "Object::Tiny::XS",
+        rate => 4340000,
+        samples => 20,
+        time => 0.231,
+        vs_slowest => 30.5,
+      },
+      {
+        errors => 3.1e-10,
         participant => "Class::XSAccessor::Array",
-        rate => 2700000,
-        samples => 27,
-        time => 0.37,
+        rate => 4400000,
+        samples => 20,
+        time => 0.23,
         vs_slowest => 31,
       },
       {
-        errors => 3.8e-10,
-        participant => "Class::XSAccessor",
-        rate => 2800000,
-        samples => 20,
-        time => 0.36,
-        vs_slowest => 32,
-      },
-      {
-        errors => 0,
+        errors => 1.1e-11,
         participant => "Mojo::Base::XS",
-        rate => 2846250,
-        samples => 20,
-        time => 0.351339,
-        vs_slowest => 32.8269,
+        rate => 4559000,
+        samples => 30,
+        time => 0.2194,
+        vs_slowest => 32.06,
       },
     ],
     {
@@ -328,7 +328,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2200.023,
+                                              speed                        => 2658.906,
                                               stepping                     => 4,
                                             },
                                             {
@@ -443,7 +443,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2199.968,
+                                              speed                        => 2732.187,
                                               stepping                     => 4,
                                             },
                                             {
@@ -558,7 +558,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2184.984,
+                                              speed                        => 2896.906,
                                               stepping                     => 4,
                                             },
                                             {
@@ -673,13 +673,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2199.968,
+                                              speed                        => "2607.500",
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.839475154876709,
+      "func.elapsed_time"              => 0.583918809890747,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::Accessors::Construction" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Class::Accessor" => 0.34,
@@ -705,32 +706,32 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors" => 0.11,
-                                            "Perl::Examples::Accessors::Array" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
-                                            "Perl::Examples::Accessors::Hash" => 0.11,
-                                            "Perl::Examples::Accessors::Mo" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
-                                            "Perl::Examples::Accessors::Moo" => 0.11,
-                                            "Perl::Examples::Accessors::Moops" => 0.11,
-                                            "Perl::Examples::Accessors::Moos" => 0.11,
-                                            "Perl::Examples::Accessors::Moose" => 0.11,
-                                            "Perl::Examples::Accessors::Mouse" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.11,
-                                            "Perl::Examples::Accessors::Scalar" => 0.11,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
+                                            "Perl::Examples::Accessors" => 0.12,
+                                            "Perl::Examples::Accessors::Array" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.12,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.12,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.12,
+                                            "Perl::Examples::Accessors::Hash" => 0.12,
+                                            "Perl::Examples::Accessors::Mo" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.12,
+                                            "Perl::Examples::Accessors::Moo" => 0.12,
+                                            "Perl::Examples::Accessors::Moops" => 0.12,
+                                            "Perl::Examples::Accessors::Moos" => 0.12,
+                                            "Perl::Examples::Accessors::Moose" => 0.12,
+                                            "Perl::Examples::Accessors::Mouse" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.12,
+                                            "Perl::Examples::Accessors::Scalar" => 0.12,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.12,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -765,9 +766,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1473472033,
       "func.scenario_module_sha1sum"   => "fe054e4d9341bef2436d320bf9748ae03e9afcf3",
       "func.scenario_module_sha256sum" => "5968ae69b1f8c09c9389560cd2948c7041f2c25ef1127405923a12b2008680f9",
-      "func.time_end"                  => 1480141028.34684,
+      "func.time_end"                  => 1485326538.19882,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1480141027.50736,
+      "func.time_start"                => 1485326537.61491,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
