@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::GeneratorStartup;
 
-our $VERSION = 0.13; # VERSION
+our $VERSION = 0.14; # VERSION
 
 our $results = [
   [
@@ -8,188 +8,257 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0008,
-        mod_overhead_time => 191,
+        errors => 0.00038,
+        mod_overhead_time => 145.2,
         participant => "Moose",
+        proc_private_dirty_size => 5,
+        proc_rss_size => 8.8,
+        proc_size => 43,
         samples => 20,
-        time => 200,
+        time => 150,
         vs_slowest => 1,
       },
       {
-        errors => 0.00019,
-        mod_overhead_time => 76,
+        errors => 0.00017,
+        mod_overhead_time => 62.2,
         participant => "Moops",
+        proc_private_dirty_size => 0.85,
+        proc_rss_size => 4.2,
+        proc_size => 16,
         samples => 20,
-        time => 85,
-        vs_slowest => 2.3,
+        time => 67,
+        vs_slowest => 2.2,
       },
       {
-        errors => 0.00019,
-        mod_overhead_time => 36,
+        errors => 0.00015,
+        mod_overhead_time => 31.2,
         participant => "Evo::Class",
+        proc_private_dirty_size => 14,
+        proc_rss_size => 18,
+        proc_size => 50,
         samples => 20,
-        time => 45,
-        vs_slowest => 4.3,
+        time => 36,
+        vs_slowest => 4.2,
       },
       {
-        errors => 0.00018,
-        mod_overhead_time => 23,
+        errors => 0.0001,
+        mod_overhead_time => 19.2,
         participant => "Mouse",
-        samples => 20,
-        time => 32,
-        vs_slowest => 6.1,
-      },
-      {
-        errors => 0.00058,
-        mod_overhead_time => 21,
-        participant => "Moo",
-        samples => 23,
-        time => 30,
-        vs_slowest => 7,
-      },
-      {
-        errors => 0.00023,
-        mod_overhead_time => 18,
-        participant => "Moos",
-        samples => 20,
-        time => 27,
-        vs_slowest => 7.3,
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.9,
+        proc_size => 19,
+        samples => 21,
+        time => 24,
+        vs_slowest => 6.3,
       },
       {
         errors => 0.00012,
-        mod_overhead_time => 13,
-        participant => "Mojo::Base",
-        samples => 20,
-        time => 22,
-        vs_slowest => 8.8,
-      },
-      {
-        errors => 0.00033,
-        mod_overhead_time => 11,
-        participant => "Class::XSAccessor",
+        mod_overhead_time => 15.2,
+        participant => "Moos",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.9,
+        proc_size => 19,
         samples => 20,
         time => 20,
-        vs_slowest => 9,
+        vs_slowest => 7.7,
       },
       {
-        errors => 0.00064,
-        mod_overhead_time => 11,
-        participant => "Object::Tiny::RW::XS",
-        samples => 22,
-        time => 20,
-        vs_slowest => 9,
-      },
-      {
-        errors => 0.00085,
-        mod_overhead_time => 11,
-        participant => "Object::Tiny::XS",
+        errors => 5.8e-05,
+        mod_overhead_time => 14.2,
+        participant => "Moo",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
         samples => 20,
-        time => 20,
-        vs_slowest => 9,
+        time => 19,
+        vs_slowest => 8.1,
       },
       {
-        errors => 3.7e-05,
-        mod_overhead_time => 11,
+        errors => 5.7e-05,
+        mod_overhead_time => 10.2,
         participant => "Class::InsideOut",
-        samples => 22,
-        time => 20,
+        proc_private_dirty_size => 1.8,
+        proc_rss_size => 5.3,
+        proc_size => 19,
+        samples => 20,
+        time => 15,
         vs_slowest => 9.8,
       },
       {
-        errors => 0.00026,
-        mod_overhead_time => 11,
-        participant => "Class::XSAccessor::Array",
+        errors => 7.6e-05,
+        mod_overhead_time => 10.2,
+        participant => "Mojo::Base",
+        proc_private_dirty_size => 0.86,
+        proc_rss_size => 4.1,
+        proc_size => 16,
         samples => 20,
-        time => 20,
-        vs_slowest => 10,
+        time => 15,
+        vs_slowest => 9.9,
       },
       {
-        errors => 3.3e-05,
-        mod_overhead_time => 8,
+        errors => 2e-05,
+        mod_overhead_time => 9.2,
         participant => "Class::Tiny",
+        proc_private_dirty_size => 2.1,
+        proc_rss_size => 5.5,
+        proc_size => 21,
         samples => 20,
-        time => 17,
+        time => 14,
         vs_slowest => 11,
       },
       {
-        errors => 3e-05,
-        mod_overhead_time => 6,
+        errors => 5.8e-05,
+        mod_overhead_time => 7.2,
         participant => "Class::Struct",
+        proc_private_dirty_size => 0.82,
+        proc_rss_size => 4.1,
+        proc_size => 16,
         samples => 20,
-        time => 15,
+        time => 12,
+        vs_slowest => 12,
+      },
+      {
+        errors => 7.1e-05,
+        mod_overhead_time => 7.2,
+        participant => "Class::XSAccessor::Array",
+        proc_private_dirty_size => 0.91,
+        proc_rss_size => 4.3,
+        proc_size => 18,
+        samples => 20,
+        time => 12,
         vs_slowest => 13,
       },
       {
-        errors => 4.5e-05,
-        mod_overhead_time => 6,
-        participant => "Class::Accessor",
+        errors => 7.5e-05,
+        mod_overhead_time => 7.2,
+        participant => "Object::Tiny::RW::XS",
+        proc_private_dirty_size => 0.82,
+        proc_rss_size => 4.1,
+        proc_size => 16,
         samples => 20,
-        time => 15,
+        time => 12,
         vs_slowest => 13,
       },
+      {
+        errors => 7.9e-05,
+        mod_overhead_time => 7.2,
+        participant => "Object::Simple",
+        proc_private_dirty_size => 3.1,
+        proc_rss_size => 6.6,
+        proc_size => 24,
+        samples => 20,
+        time => 12,
+        vs_slowest => 13,
+      },
+      {
+        errors => 5.2e-05,
+        mod_overhead_time => 7.2,
+        participant => "Object::Tiny::XS",
+        proc_private_dirty_size => 0.82,
+        proc_rss_size => 4.1,
+        proc_size => 16,
+        samples => 20,
+        time => 12,
+        vs_slowest => 13,
+      },
+      {
+        errors => 8.8e-05,
+        mod_overhead_time => 6.2,
+        participant => "Class::Accessor",
+        proc_private_dirty_size => 0.86,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 20,
+        time => 11,
+        vs_slowest => 13,
+      },
+      {
+        errors => 0.0001,
+        mod_overhead_time => 6.2,
+        participant => "Class::XSAccessor",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
+        samples => 20,
+        time => 11,
+        vs_slowest => 13,
+      },
+      {
+        errors => 3e-05,
+        mod_overhead_time => 3.6,
+        participant => "Mojo::Base::XS",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.8,
+        proc_size => 19,
+        samples => 20,
+        time => 8.4,
+        vs_slowest => 18,
+      },
+      {
+        errors => 3.1e-05,
+        mod_overhead_time => 2.7,
+        participant => "Simple::Accessor",
+        proc_private_dirty_size => 1.8,
+        proc_rss_size => 5.2,
+        proc_size => 21,
+        samples => 20,
+        time => 7.5,
+        vs_slowest => 20,
+      },
+      {
+        errors => 3.4e-05,
+        mod_overhead_time => 2.1,
+        participant => "Mo",
+        proc_private_dirty_size => 2.3,
+        proc_rss_size => 5.8,
+        proc_size => 26,
+        samples => 20,
+        time => 6.9,
+        vs_slowest => 22,
+      },
+      {
+        errors => 2.9e-05,
+        mod_overhead_time => 2.1,
+        participant => "Class::Accessor::Array",
+        proc_private_dirty_size => 1.4,
+        proc_rss_size => 4.7,
+        proc_size => 17,
+        samples => 20,
+        time => 6.9,
+        vs_slowest => 22,
+      },
+      {
+        errors => 2e-05,
+        mod_overhead_time => 1.1,
+        participant => "Object::Tiny",
+        proc_private_dirty_size => 0.86,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 21,
+        time => 5.9,
+        vs_slowest => 26,
+      },
+      {
+        errors => 2.4e-05,
+        mod_overhead_time => 1,
+        participant => "Object::Tiny::RW",
+        proc_private_dirty_size => 0.88,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 21,
+        time => 5.8,
+        vs_slowest => 26,
+      },
       {
         errors => 1.3e-05,
-        mod_overhead_time => 5.9,
-        participant => "Object::Simple",
-        samples => 20,
-        time => 14.9,
-        vs_slowest => 13.1,
-      },
-      {
-        errors => 9.9e-05,
-        mod_overhead_time => 3,
-        participant => "Mojo::Base::XS",
-        samples => 20,
-        time => 12,
-        vs_slowest => 16,
-      },
-      {
-        errors => 3.1e-05,
-        mod_overhead_time => 1,
-        participant => "Simple::Accessor",
-        samples => 20,
-        time => 10,
-        vs_slowest => 19,
-      },
-      {
-        errors => 2.1e-05,
-        mod_overhead_time => 0.699999999999999,
-        participant => "Class::Accessor::Array",
-        samples => 20,
-        time => 9.7,
-        vs_slowest => 20,
-      },
-      {
-        errors => 2.1e-05,
-        mod_overhead_time => 0.300000000000001,
-        participant => "Mo",
-        samples => 21,
-        time => 9.3,
-        vs_slowest => 21,
-      },
-      {
-        errors => 0.00016,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
-        samples => 22,
-        time => 9,
-        vs_slowest => 20,
-      },
-      {
-        errors => 3.1e-05,
-        mod_overhead_time => -1,
-        participant => "Object::Tiny::RW",
+        proc_private_dirty_size => 1.7,
+        proc_rss_size => 5.1,
+        proc_size => 19,
         samples => 20,
-        time => 8,
-        vs_slowest => 24,
-      },
-      {
-        errors => 9.1e-06,
-        mod_overhead_time => -1.1,
-        participant => "Object::Tiny",
-        samples => 20,
-        time => 7.9,
-        vs_slowest => 25,
+        time => 4.8,
+        vs_slowest => 32,
       },
     ],
     {
@@ -312,7 +381,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 1799.984,
+                                              speed                        => 2728.523,
                                               stepping                     => 4,
                                             },
                                             {
@@ -427,7 +496,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 1800.093,
+                                              speed                        => 2814.273,
                                               stepping                     => 4,
                                             },
                                             {
@@ -542,7 +611,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 1799.984,
+                                              speed                        => 2792.781,
                                               stepping                     => 4,
                                             },
                                             {
@@ -657,13 +726,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 1799.984,
+                                              speed                        => "2805.250",
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 18.1830599308014,
+      "func.elapsed_time"              => 11.4260718822479,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
+                                            "__PACKAGE__"                                    => 1.034,
                                             "Bencher::Scenario::Accessors::GeneratorStartup" => undef,
                                             "Benchmark::Dumb"                                => "0.10",
                                             "Class::Accessor"                                => 0.34,
@@ -723,13 +793,26 @@ our $results = [
       "func.scenario_module_mtime"     => 1459169292,
       "func.scenario_module_sha1sum"   => "8ca3e295d90cab65e0de29ab5e887d7eb667bf8d",
       "func.scenario_module_sha256sum" => "ae94f28e6695e34d05c797d499629801c18c6d478feb5058fb4270ecf4c81ddb",
-      "func.time_end"                  => 1480141047.39788,
+      "func.time_end"                  => 1485326551.29512,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1480141029.21482,
-      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
-      "table.field_units"              => [undef, "ms", "ms"],
+      "func.time_start"                => 1485326539.86905,
+      "table.field_aligns"             => [
+                                            "left",
+                                            "left",
+                                            "left",
+                                            "left",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                          ],
+      "table.field_units"              => [undef, "MB", "MB", "MB", "ms", "ms"],
       "table.fields"                   => [
                                             "participant",
+                                            "proc_private_dirty_size",
+                                            "proc_rss_size",
+                                            "proc_size",
                                             "time",
                                             "mod_overhead_time",
                                             "vs_slowest",
