@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::Get;
 
-our $VERSION = 0.13; # VERSION
+our $VERSION = 0.14; # VERSION
 
 our $results = [
   [
@@ -8,212 +8,212 @@ our $results = [
     "OK",
     [
       {
-        errors => 4.3e-10,
+        errors => 1.2e-11,
         participant => "Class::Accessor",
-        rate => 1970000,
-        samples => 26,
-        time => 507,
+        rate => 2011000,
+        samples => 22,
+        time => 497.3,
         vs_slowest => 1,
       },
       {
-        errors => 3.7e-09,
-        participant => "Class::InsideOut",
-        rate => 2400000,
-        samples => 20,
-        time => 410,
-        vs_slowest => 1.2,
-      },
-      {
-        errors => 4.3e-10,
+        errors => 1.1e-11,
         participant => "Simple::Accessor",
-        rate => 2600000,
-        samples => 24,
-        time => 380,
-        vs_slowest => 1.3,
-      },
-      {
-        errors => 2.6e-09,
-        participant => "Evo::Class",
-        rate => 3800000,
+        rate => 2834000,
         samples => 20,
-        time => 260,
-        vs_slowest => 1.9,
+        time => 352.8,
+        vs_slowest => 1.409,
       },
       {
-        errors => 1.1e-10,
-        participant => "Class::Struct",
-        rate => 4080000,
-        samples => 20,
-        time => 245,
-        vs_slowest => 2.07,
-      },
-      {
-        errors => 0,
-        participant => "Object::Tiny::RW",
-        rate => 4588390,
-        samples => 20,
-        time => 217.941,
-        vs_slowest => 2.32703,
-      },
-      {
-        errors => 1.1e-11,
-        participant => "no generator (hash-based)",
-        rate => 4611000,
-        samples => 20,
-        time => 216.9,
-        vs_slowest => 2.339,
-      },
-      {
-        errors => 3.1e-10,
-        participant => "Mo",
-        rate => 4600000,
-        samples => 23,
-        time => 220,
-        vs_slowest => 2.3,
-      },
-      {
-        errors => 1.1e-11,
-        participant => "Class::Tiny",
-        rate => 4897000,
-        samples => 20,
-        time => 204.2,
-        vs_slowest => 2.484,
+        errors => 3e-10,
+        participant => "Class::InsideOut",
+        rate => 3250000,
+        samples => 21,
+        time => 308,
+        vs_slowest => 1.61,
       },
       {
         errors => 1e-10,
-        participant => "Object::Simple",
-        rate => 5090000,
+        participant => "Class::Struct",
+        rate => 4320000,
         samples => 20,
-        time => 196,
-        vs_slowest => 2.58,
-      },
-      {
-        errors => 2.7e-09,
-        participant => "Mojo::Base",
-        rate => 7000000,
-        samples => 20,
-        time => 200,
-        vs_slowest => 3,
-      },
-      {
-        errors => 2.3e-10,
-        participant => "Object::Tiny",
-        rate => 7100000,
-        samples => 20,
-        time => 140,
-        vs_slowest => 3.6,
-      },
-      {
-        errors => 2.7e-09,
-        participant => "no generator (array-based)",
-        rate => 8000000,
-        samples => 20,
-        time => 100,
-        vs_slowest => 4,
-      },
-      {
-        errors => 8.3e-10,
-        participant => "Class::XSAccessor",
-        rate => 9000000,
-        samples => 20,
-        time => 110,
-        vs_slowest => 4.5,
-      },
-      {
-        errors => 4.4e-10,
-        participant => "Mojo::Base::XS",
-        rate => 9100000,
-        samples => 24,
-        time => 110,
-        vs_slowest => 4.6,
-      },
-      {
-        errors => 1e-09,
-        participant => "Moo",
-        rate => 9600000,
-        samples => 23,
-        time => 100,
-        vs_slowest => 4.9,
+        time => 231,
+        vs_slowest => 2.15,
       },
       {
         errors => 3.1e-10,
-        participant => "Mouse",
-        rate => 11000000,
-        samples => 30,
-        time => 94,
-        vs_slowest => 5.4,
+        participant => "Mojo::Base",
+        rate => 4900000,
+        samples => 20,
+        time => 210,
+        vs_slowest => 2.4,
       },
       {
-        errors => 2.4e-10,
-        participant => "Object::Tiny::RW::XS",
-        rate => 12000000,
+        errors => 4.2e-10,
+        participant => "Mo",
+        rate => 5000000,
         samples => 20,
-        time => 86,
-        vs_slowest => 5.9,
+        time => 200,
+        vs_slowest => 2.5,
       },
       {
-        errors => 8.9e-10,
-        participant => "Class::XSAccessor::Array",
-        rate => 10000000,
+        errors => 1.1e-11,
+        participant => "Object::Tiny::RW",
+        rate => 5588000,
         samples => 20,
-        time => 80,
-        vs_slowest => 6,
+        time => 179,
+        vs_slowest => 2.779,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "no generator (array-based)",
+        rate => 5588000,
+        samples => 20,
+        time => 178.9,
+        vs_slowest => 2.779,
+      },
+      {
+        errors => 3.1e-10,
+        participant => "Object::Simple",
+        rate => 5800000,
+        samples => 20,
+        time => 170,
+        vs_slowest => 2.9,
+      },
+      {
+        errors => 1.2e-11,
+        participant => "Evo::Class",
+        rate => 5846000,
+        samples => 20,
+        time => 171,
+        vs_slowest => 2.907,
+      },
+      {
+        errors => 1e-10,
+        participant => "no generator (hash-based)",
+        rate => 6010000,
+        samples => 20,
+        time => 166,
+        vs_slowest => 2.99,
+      },
+      {
+        errors => 3.1e-10,
+        participant => "Class::Accessor::Array",
+        rate => 6400000,
+        samples => 20,
+        time => 160,
+        vs_slowest => 3.2,
+      },
+      {
+        errors => 4.2e-10,
+        participant => "Moose",
+        rate => 6600000,
+        samples => 20,
+        time => 150,
+        vs_slowest => 3.3,
       },
       {
         errors => 2.9e-10,
+        participant => "Class::Tiny",
+        rate => 6800000,
+        samples => 20,
+        time => 150,
+        vs_slowest => 3.4,
+      },
+      {
+        errors => 1.9e-10,
+        participant => "Object::Tiny",
+        rate => 8800000,
+        samples => 23,
+        time => 110,
+        vs_slowest => 4.4,
+      },
+      {
+        errors => 1.4e-10,
+        participant => "Mouse",
+        rate => 10000000,
+        samples => 20,
+        time => 99,
+        vs_slowest => 5,
+      },
+      {
+        errors => 5.3e-11,
         participant => "Object::Tiny::XS",
-        rate => 13000000,
+        rate => 11400000,
         samples => 20,
-        time => 79,
-        vs_slowest => 6.4,
+        time => 87.9,
+        vs_slowest => 5.66,
       },
       {
-        errors => 7.4e-10,
-        participant => "Moose",
-        rate => 13000000,
+        errors => 3.4e-10,
+        participant => "Mojo::Base::XS",
+        rate => 12000000,
         samples => 20,
-        time => 79,
-        vs_slowest => 6.5,
+        time => 87,
+        vs_slowest => 5.7,
       },
       {
-        errors => 2.6e-10,
+        errors => 1.6e-10,
+        participant => "Moos",
+        rate => 12000000,
+        samples => 20,
+        time => 81,
+        vs_slowest => 6.1,
+      },
+      {
+        errors => 1.6e-10,
         participant => "Moops",
         rate => 13000000,
         samples => 20,
         time => 78,
-        vs_slowest => 6.5,
+        vs_slowest => 6.3,
       },
       {
-        errors => 9.5e-10,
-        participant => "Class::Accessor::Array",
-        rate => 10000000,
+        errors => 2.4e-10,
+        participant => "Object::Tiny::RW::XS",
+        rate => 13000000,
+        samples => 24,
+        time => 77,
+        vs_slowest => 6.4,
+      },
+      {
+        errors => 1.5e-10,
+        participant => "Class::XSAccessor",
+        rate => 13000000,
+        samples => 21,
+        time => 75,
+        vs_slowest => 6.6,
+      },
+      {
+        errors => 4.6e-11,
+        participant => "Moo",
+        rate => 14500000,
+        samples => 21,
+        time => 69.1,
+        vs_slowest => 7.2,
+      },
+      {
+        errors => 6.3e-11,
+        participant => "Class::XSAccessor::Array",
+        rate => 19000000,
         samples => 20,
-        time => 80,
-        vs_slowest => 7,
+        time => 53,
+        vs_slowest => 9.3,
       },
       {
-        errors => 1.7e-10,
+        errors => 2.1e-10,
         participant => "raw hash access",
-        rate => 21000000,
-        samples => 29,
-        time => 49,
-        vs_slowest => 10,
+        rate => 32000000,
+        samples => 20,
+        time => 32,
+        vs_slowest => 16,
       },
       {
-        errors => 0,
+        errors => 1e-11,
         participant => "raw array access",
-        rate => 30791900,
+        rate => 49500000,
         samples => 20,
-        time => 32.4761,
-        vs_slowest => 15.6163,
-      },
-      {
-        errors => 8.5e-10,
-        participant => "Moos",
-        rate => -70000000,
-        samples => 20,
-        time => -10,
-        vs_slowest => -40,
+        time => 20.2,
+        vs_slowest => 24.6,
       },
     ],
     {
@@ -336,7 +336,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 1852.921,
+                                              speed                        => "2819.140",
                                               stepping                     => 4,
                                             },
                                             {
@@ -451,7 +451,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 1884.914,
+                                              speed                        => 2600.718,
                                               stepping                     => 4,
                                             },
                                             {
@@ -566,7 +566,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 1899.953,
+                                              speed                        => 2878.312,
                                               stepping                     => 4,
                                             },
                                             {
@@ -681,13 +681,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => "1888.960",
+                                              speed                        => 2600.117,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.760756015777588,
+      "func.elapsed_time"              => 0.646871089935303,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::Accessors::Get" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Class::Accessor" => 0.34,
@@ -713,30 +714,30 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors::Array" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
-                                            "Perl::Examples::Accessors::Hash" => 0.11,
-                                            "Perl::Examples::Accessors::Mo" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
-                                            "Perl::Examples::Accessors::Moo" => 0.11,
-                                            "Perl::Examples::Accessors::Moops" => 0.11,
-                                            "Perl::Examples::Accessors::Moos" => 0.11,
-                                            "Perl::Examples::Accessors::Moose" => 0.11,
-                                            "Perl::Examples::Accessors::Mouse" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.11,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::Array" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.12,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.12,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.12,
+                                            "Perl::Examples::Accessors::Hash" => 0.12,
+                                            "Perl::Examples::Accessors::Mo" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.12,
+                                            "Perl::Examples::Accessors::Moo" => 0.12,
+                                            "Perl::Examples::Accessors::Moops" => 0.12,
+                                            "Perl::Examples::Accessors::Moos" => 0.12,
+                                            "Perl::Examples::Accessors::Moose" => 0.12,
+                                            "Perl::Examples::Accessors::Mouse" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.12,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.12,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -771,9 +772,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1480140843,
       "func.scenario_module_sha1sum"   => "0041085ad18b13f697b5c45fcaf6b63db5224ecf",
       "func.scenario_module_sha256sum" => "a4c8ae55843097cf2f1e87f32abec3865d39262c08b02468601d96d8a5894d6a",
-      "func.time_end"                  => 1480141048.45846,
+      "func.time_end"                  => 1485326552.12542,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1480141047.69771,
+      "func.time_start"                => 1485326551.47854,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ns"],
       "table.fields"                   => [
