@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::Set;
 
-our $VERSION = 0.13; # VERSION
+our $VERSION = 0.14; # VERSION
 
 our $results = [
   [
@@ -8,196 +8,196 @@ our $results = [
     "OK",
     [
       {
-        errors => 1.7e-09,
+        errors => 1.4e-09,
         participant => "Simple::Accessor",
-        rate => 198000,
-        samples => 20,
-        time => 5.04,
+        rate => 264000,
+        samples => 30,
+        time => 3.79,
         vs_slowest => 1,
       },
       {
-        errors => 3.9e-10,
+        errors => 8.1e-10,
         participant => "Class::Accessor",
-        rate => 1600000,
-        samples => 20,
-        time => 0.627,
-        vs_slowest => 8.04,
+        rate => 1700000,
+        samples => 21,
+        time => 0.57,
+        vs_slowest => 6.6,
       },
       {
         errors => 2.1e-10,
         participant => "Class::InsideOut",
-        rate => 1970000,
+        rate => 2550000,
         samples => 20,
-        time => 0.507,
-        vs_slowest => 9.93,
+        time => 0.392,
+        vs_slowest => 9.65,
       },
       {
-        errors => 1.7e-10,
-        participant => "Object::Tiny::RW",
-        rate => 2970000,
-        samples => 32,
-        time => 0.337,
+        errors => 4.2e-10,
+        participant => "Evo::Class",
+        rate => 3900000,
+        samples => 20,
+        time => 0.26,
         vs_slowest => 15,
       },
       {
-        errors => 8.5e-10,
-        participant => "Evo::Class",
-        rate => 3200000,
-        samples => 20,
-        time => 0.31,
-        vs_slowest => 16,
+        errors => 8.7e-11,
+        participant => "Class::Struct",
+        rate => 4330000,
+        samples => 29,
+        time => 0.231,
+        vs_slowest => 16.4,
       },
       {
-        errors => 8.2e-10,
-        participant => "Class::Struct",
-        rate => 3200000,
-        samples => 21,
-        time => 0.31,
-        vs_slowest => 16,
+        errors => 1e-11,
+        participant => "Moose",
+        rate => 4337000,
+        samples => 20,
+        time => 0.2306,
+        vs_slowest => 16.42,
       },
       {
         errors => 4.2e-10,
-        participant => "Class::Tiny",
-        rate => 3400000,
+        participant => "Object::Tiny::RW",
+        rate => 4400000,
         samples => 20,
-        time => 0.29,
+        time => 0.23,
         vs_slowest => 17,
       },
       {
-        errors => 2.1e-10,
-        participant => "Moose",
-        rate => 3440000,
-        samples => 23,
-        time => 0.291,
-        vs_slowest => 17.3,
-      },
-      {
-        errors => 1.1e-10,
-        participant => "Mojo::Base",
-        rate => 3550000,
-        samples => 20,
-        time => 0.282,
-        vs_slowest => 17.9,
-      },
-      {
-        errors => 5.1e-10,
-        participant => "Object::Simple",
-        rate => 4200000,
-        samples => 20,
-        time => 0.24,
-        vs_slowest => 21,
-      },
-      {
-        errors => 3.5e-10,
-        participant => "no generator (array-based)",
-        rate => 4500000,
-        samples => 23,
-        time => 0.22,
-        vs_slowest => 23,
-      },
-      {
-        errors => 4.3e-10,
-        participant => "no generator (hash-based)",
-        rate => 4600000,
-        samples => 20,
-        time => 0.22,
-        vs_slowest => 23,
-      },
-      {
-        errors => 4.8e-10,
+        errors => 1e-10,
         participant => "Mo",
-        rate => 4800000,
-        samples => 29,
-        time => 0.21,
-        vs_slowest => 24,
+        rate => 4480000,
+        samples => 20,
+        time => 0.223,
+        vs_slowest => 16.9,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "Class::Accessor::Array",
+        rate => 4561000,
+        samples => 24,
+        time => 0.2193,
+        vs_slowest => 17.27,
+      },
+      {
+        errors => 1e-10,
+        participant => "Mojo::Base",
+        rate => 5030000,
+        samples => 20,
+        time => 0.199,
+        vs_slowest => 19,
       },
       {
         errors => 4.4e-10,
-        participant => "Class::Accessor::Array",
-        rate => 5400000,
-        samples => 20,
-        time => 0.18,
-        vs_slowest => 27,
-      },
-      {
-        errors => 4.2e-10,
-        participant => "Mojo::Base::XS",
-        rate => 6600000,
-        samples => 20,
-        time => 0.15,
-        vs_slowest => 33,
-      },
-      {
-        errors => 0,
-        participant => "Moos",
-        rate => 6772030,
-        samples => 20,
-        time => 0.147666,
-        vs_slowest => 34.135,
-      },
-      {
-        errors => 3.1e-10,
-        participant => "Class::XSAccessor",
-        rate => 7100000,
-        samples => 20,
-        time => 0.14,
-        vs_slowest => 36,
-      },
-      {
-        errors => 2.3e-10,
-        participant => "Moo",
-        rate => 8000000,
-        samples => 25,
-        time => 0.13,
-        vs_slowest => 40,
-      },
-      {
-        errors => 3.5e-11,
-        participant => "Object::Tiny::RW::XS",
-        rate => 8330000,
-        samples => 20,
-        time => 0.12,
-        vs_slowest => 42,
+        participant => "Class::Tiny",
+        rate => 5100000,
+        samples => 21,
+        time => 0.2,
+        vs_slowest => 19,
       },
       {
         errors => 1.2e-11,
-        participant => "Moops",
-        rate => 8629000,
+        participant => "Object::Simple",
+        rate => 5241000,
         samples => 20,
-        time => 0.1159,
-        vs_slowest => 43.49,
+        time => 0.1908,
+        vs_slowest => 19.84,
       },
       {
-        errors => 1.7e-10,
-        participant => "Class::XSAccessor::Array",
-        rate => 8800000,
+        errors => 9.8e-11,
+        participant => "no generator (hash-based)",
+        rate => 5860000,
+        samples => 26,
+        time => 0.171,
+        vs_slowest => 22.2,
+      },
+      {
+        errors => 9.8e-12,
+        participant => "no generator (array-based)",
+        rate => 6399000,
+        samples => 20,
+        time => 0.1563,
+        vs_slowest => 24.23,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "Mouse",
+        rate => 9180000,
+        samples => 26,
+        time => 0.109,
+        vs_slowest => 34.7,
+      },
+      {
+        errors => 2.1e-10,
+        participant => "Moops",
+        rate => 9500000,
         samples => 20,
         time => 0.11,
-        vs_slowest => 44,
+        vs_slowest => 36,
       },
       {
-        errors => 7.3e-10,
-        participant => "Mouse",
+        errors => 2.6e-10,
+        participant => "Mojo::Base::XS",
+        rate => 9500000,
+        samples => 20,
+        time => 0.1,
+        vs_slowest => 36,
+      },
+      {
+        errors => 1.1e-11,
+        participant => "Class::XSAccessor",
+        rate => 9550000,
+        samples => 20,
+        time => 0.105,
+        vs_slowest => 36.2,
+      },
+      {
+        errors => 1.6e-10,
+        participant => "Moos",
+        rate => 10000000,
+        samples => 20,
+        time => 0.098,
+        vs_slowest => 39,
+      },
+      {
+        errors => 2e-10,
+        participant => "Object::Tiny::RW::XS",
+        rate => 11000000,
+        samples => 21,
+        time => 0.095,
+        vs_slowest => 40,
+      },
+      {
+        errors => 1.5e-10,
+        participant => "Class::XSAccessor::Array",
+        rate => 11000000,
+        samples => 22,
+        time => 0.094,
+        vs_slowest => 40,
+      },
+      {
+        errors => 2.1e-10,
+        participant => "Moo",
+        rate => 12000000,
+        samples => 21,
+        time => 0.082,
+        vs_slowest => 46,
+      },
+      {
+        errors => 4.2e-09,
+        participant => "raw array access",
         rate => 10000000,
         samples => 20,
         time => 0.07,
-        vs_slowest => 70,
+        vs_slowest => 50,
       },
       {
-        errors => 1.1e-10,
+        errors => 1.6e-10,
         participant => "raw hash access",
         rate => 15000000,
         samples => 20,
         time => 0.067,
-        vs_slowest => 75,
-      },
-      {
-        errors => 1.1e-10,
-        participant => "raw array access",
-        rate => 18000000,
-        samples => 20,
-        time => 0.056,
-        vs_slowest => 91,
+        vs_slowest => 56,
       },
     ],
     {
@@ -320,7 +320,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2085.890",
+                                              speed                        => 2872.679,
                                               stepping                     => 4,
                                             },
                                             {
@@ -435,7 +435,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2060.789,
+                                              speed                        => 2872.789,
                                               stepping                     => 4,
                                             },
                                             {
@@ -550,7 +550,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2026.171,
+                                              speed                        => 2707.085,
                                               stepping                     => 4,
                                             },
                                             {
@@ -665,13 +665,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2061.335,
+                                              speed                        => 2882.906,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.698377132415771,
+      "func.elapsed_time"              => 0.575912952423096,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::Accessors::Set" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Class::Accessor" => 0.34,
@@ -697,28 +698,28 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors::Array" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
-                                            "Perl::Examples::Accessors::Hash" => 0.11,
-                                            "Perl::Examples::Accessors::Mo" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
-                                            "Perl::Examples::Accessors::Moo" => 0.11,
-                                            "Perl::Examples::Accessors::Moops" => 0.11,
-                                            "Perl::Examples::Accessors::Moos" => 0.11,
-                                            "Perl::Examples::Accessors::Moose" => 0.11,
-                                            "Perl::Examples::Accessors::Mouse" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::Array" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.12,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.12,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.12,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.12,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.12,
+                                            "Perl::Examples::Accessors::Hash" => 0.12,
+                                            "Perl::Examples::Accessors::Mo" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.12,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.12,
+                                            "Perl::Examples::Accessors::Moo" => 0.12,
+                                            "Perl::Examples::Accessors::Moops" => 0.12,
+                                            "Perl::Examples::Accessors::Moos" => 0.12,
+                                            "Perl::Examples::Accessors::Moose" => 0.12,
+                                            "Perl::Examples::Accessors::Mouse" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.12,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.12,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.12,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -753,9 +754,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1480075844,
       "func.scenario_module_sha1sum"   => "04b532534e4dbeb4059ed136136014e705973784",
       "func.scenario_module_sha256sum" => "57e2384e577a0864ee7a5b36cca5e886c5eb6b028245a2cd7b80d5b8e26b1ab6",
-      "func.time_end"                  => 1480141049.45434,
+      "func.time_end"                  => 1485326552.89288,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1480141048.75596,
+      "func.time_start"                => 1485326552.31697,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
